SalmAlm Dashboard

← Back to Chat

# 😈 SalmAlm Dashboard

### 💰 Total Cost

$0.00

### 💬 Sessions

0

### 🔧 Tool Calls (24h)

0

### 📡 Status

Loading...

### 📊 Tool Usage (24h)

### 💸 Cost by Model

### 🧠 Model Usage

Model | Calls | Tokens In | Tokens Out | Cost
--- | --- | --- | --- | ---

### 📊 SLA Dashboard

Uptime
—
—
TTFT P95
—
target: —
Response P95
—
target: —
Monthly Uptime
—
target: —
Response Time Trend (recent)
Recent Incidents
—

### 📋 Audit Log

Time | Type | Session | Detail
--- | --- | --- | ---
Loading...

### ⏰ Cron Jobs

None

### 🧩 Plugins

None